#
# spec file for package doomsday
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           doomsday
Version:        2.3.1
Release:        2.13
Summary:        The Doomsday Engine: DOOM/Hertic/Hexen port with pretty graphics
License:        BSD-3-Clause AND GPL-2.0-only AND GPL-2.0-or-later AND SUSE-GPL-2.0-with-linking-exception AND LGPL-3.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            http://dengine.net/
Source:         Doomsday-Engine-%version.tar.xz
Source2:        %name-rpmlintrc
Patch1:         doomsday-no-abs-icon.patch
Patch2:         doomsday-libs.diff
Patch3:         doomsday-notime.diff
BuildRequires:  Mesa-devel
BuildRequires:  cmake
BuildRequires:  gcc-c++ >= 6
BuildRequires:  libcurl4
BuildRequires:  libpng-devel
BuildRequires:  ncurses-devel
BuildRequires:  zlib-devel
BuildRequires:  zziplib-devel
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5OpenGLExtensions)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xxf86vm)
# Mesa 9.2 has OpenGL 3.1, and doomsday 2.0 needs that.
Requires:       Mesa-libGL1 >= 9.2
# Doomsday uses a modified version of assimp, so no pkgconfig(assimp) here :-(
Provides:       jdoom = %version-%release
Provides:       jheretic = %version-%release
Provides:       jhexen = %version-%release
Provides:       bundled(assimp) = 3.3.1
Obsoletes:      deng < %version-%release
Provides:       deng = %version-%release

%description
The Doomsday Engine is a source port with support for Doom, Heretic,
and Hexen. It does not support BOOM extensions.

%prep
%autosetup -p1 -n Doomsday-Engine-%version

%build
pushd doomsday
%cmake \
%ifarch aarch64 %arm
	-DDENG_OPENGL_API=GLES3 \
%endif
	-DCMAKE_SKIP_RPATH:BOOL=ON
%make_build -O

%install
b="%buildroot"
pushd doomsday/
%cmake_install
popd
d="$b/%_libdir/doomsday"
rm -Rf "$b/%_includedir" "$b/%_libdir/cmake" "$b/%_datadir/doc/texc" \
	"$d/cmake" "$d/pkgconfig" "$d"/*.a
mkdir -p "$b/%_datadir/pixmaps"
ln -s "%_datadir/%name/deng-shell-logo-256.png" "$b/%_datadir/pixmaps/"
ln -s "%_datadir/%name/deng-logo-256.png" "$b/%_datadir/pixmaps/"

mkdir -p "$b/%_sysconfdir/doomsday";
cat >"$b/%_sysconfdir/doomsday/paths" <<-EOF
	basedir: %_datadir/doomsday
	libdir: %_libdir/doomsday
	iwaddir: %_datadir/doom
EOF

%post
echo "INFO: %name: The global IWAD directory is %_datadir/doom.";
/sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%dir %_sysconfdir/doomsday
%config %_sysconfdir/doomsday/paths
%_bindir/*
%_libdir/libdeng*.so*
%_libdir/%name/
%_datadir/%name/
%_datadir/applications/*.desktop
%_datadir/metainfo/
%_datadir/icons/*
%_datadir/pixmaps/*.png

%changelog
* Sat Jun 26 2021 Jan Engelhardt <jengelh@inai.de>
- Drop unused launcher subpackage.
* Wed Mar 10 2021 Yevgeny Sliosarenko <musicsuse@gmx.com>
- Updated to release 2.3.1
- What's new in 2.3.1:
  * This version improves support for vanilla DOOM render hacks and adds more script bindings to manipulate things in the map.
    DOOM render hacks. TNT: Evilution and The Plutonia Experiment use several render/map hacks to take advantage of quirks in the original DOOM renderer.
    Many of these effects are now supported (or fixed) in Doomsday.
    Examples: TNT MAP02 deep water, TNT MAP02 windows overlooking the deep water, TNT MAP09 transparent window, TNT MAP31 Arachnotrons inside pillars.
    Scripting. Several new Doomsday Script bindings were added, allowing access to game, player, and thing properties.
    In addition to spawning things, one can now list things by type, check their state and flags, and perform state changes on them.
    Things can also have an “On death” script that gets run when the thing dies. Bitwise operators are now available in scripts.
    Modding. Sprite renaming is supported via DeHackEd.
    In Heretic, ambient sound sequences can be redefined and new ones can be added via the Audio module.
    Changing the sequences is also possible during gameplay. The earthquake effect from Hexen is now also available in Heretic.
    It can be controlled via scripts.
    Renderer. Player HUD weapon models may specify a custom FOV value for rendering so that model authors have more control over the appearance, for instance to replicate a 2D sprite appearance more faithfully.
  * Patch release for 2.3 that fixes some incorrect behavior:
    Heretic: Sky textures are only partially visible.
    Hexen: Sky textures are sized incorrectly.
    Alignment of floor/ceiling textures whose size is not 64×64.
* Tue Sep 15 2020 Jan Engelhardt <jengelh@inai.de>
- Drop recommendation for timidity, this backend is not selectable
  from the game.
* Thu Aug 20 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Use openGL ES 3 for aarch64 and %%arm
* Sun Mar 29 2020 Jan Engelhardt <jengelh@inai.de>
- Add -DCMAKE_SKIP_RPATH
* Thu Mar  5 2020 Jan Engelhardt <jengelh@inai.de>
- Add -lminizip to doomsday-libs.diff to cure a linker error.
- Update to release 2.2.2
  * Doomsday Script improvements, Heretic modding, weapon
    field of view.
* Sun Jan 19 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.2.1.1
  * The built-in scripting language has gained wider integration
    in the engine internals.
  * Scripted mobj actions
  * A number of modding related improvements have been done for
    Heretic. For example: customizable menu labels, enhanced
    intermission screen, Values for ammo per shot, support for
    Hexen-like wall-bouncing missiles, and a script binding for
    starting an enemy’s attack.
  * Separate FOV for rendering player weapons
  * Doomsday now detects Freedoom v0.12.1.
* Sat Nov  2 2019 Jan Engelhardt <jengelh@inai.de>
- Previous implicit dependency on xxf86vm is now added
  as an explicit BuildRequires.
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 2.1.1
  * Graphics optimizations: While games still use the classic
    renderer like in 2.0, all graphics are now drawn using OpenGL
    3.3. This enables optimizations for more efficient rendering
    of the player view, menus, text, and the Doomsday UI.
  * UI improvements: The Doomsday UI look and feel has been
    refreshed. The game library is now more flexible and powerful
    with further game customization settings and view options.
  * Multiplayer convenience: Clients will automatically download
    missing PWADs from the server before joining the game.
* Thu Feb  8 2018 jengelh@inai.de
- Get rid of BuildRequires: xorg-x11-devel.
* Sun Jan 14 2018 jengelh@inai.de
- Add bundled() markers
* Thu Dec 14 2017 jengelh@inai.de
- Update to new bugfix release 2.0.3
  * Server had crashed during startup with error messages related
    to threading
  * Non-standard C++ code had led to crash when using gcc7
  * Removed duplicate IWAD spec for Heretic 1.3 /
    Shadow of the Serpent Riders
  * Hexen: fix crash after returning to a different map in a hub
- Add doomsday-libs.diff, doomsday-notime.diff
* Thu Apr 20 2017 jengelh@inai.de
- Update to new upstream release 2.0
  * The Home Screen replaces the front-end app. The Python-based
    Snowberry launcher application was created in 2005 and has been
    used for starting Doomsday ever since. In version 2.0, the
    launcher is no longer needed because Doomsday's Home Screen
    (previously called "ring zero") replaces its functionality.
  * Built-in support for packages. One of the launcher's key features
    was add-on management. This is now also part of Doomsday itself
    in the form of packages. Anything that Doomsday can load — WADs,
    resource packs, 3D models, etc. — is now handled via the same
    package management system. This enables Doomsday to track which
    files are in use in saved games and multiplayer games, and makes
    it possible to automatically ensure that the correct files are
    loaded at any given time.
  * New 3D model renderer. Doomsday's graphics code is undergoing a
    transition to a newer version of OpenGL, namely "OpenGL3/4 Core
    Profile"). Certain parts like the engine UI have already
    completed this transition, however the game renderer itself has
    not. In version 2.0, the new version of the 3D model renderer has
    reached a state where it is useful for actual gameplay. This new
    renderer supports FBX and MD5 models (among other formats),
    skeletal animation, GLSL shaders, and Doomsday Script.
* Sat Jun 18 2016 jengelh@inai.de
- Update to new upstream release 1.15.8
  * Custom episodes. Episode (DED) definitions specify the structure of
  game episodes (including hubs) enabling entirely new episodes and
  modifying the originals.
  * MAPINFO support. MAPINFO (Hexen) definitions are now supported in
  Doom and Heretic, as well as Hexen. Note that, presently, only the
  Hexen dialect of MAPINFO is supported (ZDoom uses its own MAPINFO
  dialect).
  * Adjustable pixel density. If your GPU is on the slower side, you
  can improve performance by reducing game view resolution. The rest
  of the UI remains sharp since the display mode is not changed. As a
  bonus, you can also get a nice nostalgic aesthetic similar to the
  original Doom on a CRT display.
- If you get a blank screen instead of the game title screen
  after selecting the IWAD to play, you may need to reset your
  settings (~/.doomsday)!
- Added doomsday-ncurses.diff (work around absence of ncurses.pc
  in not-too-new ncurses)
* Thu Jun 16 2016 jengelh@inai.de
- Add -Wno-narrowing to let gcc6 build pass
* Mon Mar 30 2015 dimstar@opensuse.org
- Add doomsday-no-abs-icon.patch: Do not use absolute path to
  icons. Applicatio containerisation requires the icons to be below
  /usr/share/icons or /usr/share/pixmaps.
- Copy the icons from the app directory to /usr/share/pixmaps.
* Sun Oct 12 2014 jengelh@inai.de
- Update to new upstream release 1.14.5, which fixes:
  * Hexen: Loading autosaved progress on a previously visited map
  loads an out of date save state
  * Hexen: Number of inventory items increases when going through
  a portal
  * Hexen: Puzzle progress in main hub not showing up
* Tue May 20 2014 jengelh@inai.de
- Update to new upstream release 1.14.3, which fixes:
  * Hexen: Hub maps reset after saving, causing invalid game world
  state
  * Doom 2: Crash playing sci2.wad MAP13
  * Better compatibility with vanilla Doom renderer: dynamic
  map hacks dependent on non-neighbor planes
  * Hexen: Saving error — "already exists"
* Thu May  1 2014 jengelh@inai.de
- Update to new upstream release 1.14.1, which fixes:
  * particles were shut off shortly after level start
  * flickering light decoration on moving platform
  * letterboxed/pillarboxed drawing of the game was broken
  * Heretic ghost mummies' floating spirits were not disappearing
  after death
  * Shift key state was not recognized by bindings when typing in
  console
  * Multiplayer weapons were not remaining in play
  * Gracefully abort if OpenGL version is not sufficient
* Wed Apr 23 2014 jengelh@inai.de
- Update to new upstream release 1.14
  * It adds bloom to Doomsday's visual features. The last of the
  old UI has been replaced, and now MP games and save games, due
  to a new save game format, from all games can be accessed from
  the taskbar or home screen (formerly Ring Zero). New alert and
  tutorial notifications have been added to inform users of any
  important engine, map and resource errors and about the UI.
* Mon Jan  6 2014 jengelh@inai.de
- Update to new upstream release 1.13.1
  * Multiplayer: Resolve crash when joining a multiplayer game using
  the Vanilla appearance profile
  * Multiplayer: Resolve crash when more than one client joins a game
  * Multiplayer: Missing busy mode transition frame when joining
  a game
  * UI: Using keyboard bindings when a popup is open in the UI
  (e.g. pressing F11 to toggle screen when the DE menu is open in
  the task bar)
  * Added the -nodiscovery option to prevent Doomsday from looking
  for running servers on the LAN
* Fri Jan  3 2014 jengelh@inai.de
- Update to new upstream release 1.13
  * Framebuffer effects. Doomsday can now use OpenGL shaders to
  post-process the rendered frames. In this release, this has been
  applied this for libdoom's Invulnerability power-up effect.
  * Stereoscopic 3D. Support has been added for various stereoscopic
  rendering modes, including anaglyph, side-by-side, parallel and
  cross-eyed viewing.
* Mon Nov 11 2013 jengelh@inai.de
- Update to new upstream release 1.12.2
  * console: fix crash when autocompleting certain words (e.g. "upd")
  * task bar: Added toggle for sound-overlap-stop to Audio Settings:
  when enabled, only one sound is allowed per emitter (like in the
  original games)
- Remove deng-va-list.diff (merged upstream)
- OpenGL 2.x is required for Doomsday 1.12
* Sun Oct  6 2013 jengelh@inai.de
- Update to new upstream release 1.12
  * The old Control Panel and Updater have been retired and their
  functionality merged into the taskbar. New taskbar features
  include background downloading of updates, profiles for renderer
  settings, and auto completion of console commands. There is also
  vastly improved map rendering hack support, and 3D sound can now
  separate isolated parts of joined sectors.
* Tue Jul 30 2013 jengelh@inai.de
- Update to new upstream release 1.11.0
  * Doomsday has received a new mouse-driven UI; the taskbar
  replaces the old console.
* Thu May 23 2013 jengelh@inai.de
- Update to new upstream release 1.10.3
  * resolve stuck TEXTUREn lump loading with Hell Revealed II
  * fog should not be applied to weapon psprites
- Remove deng-nodate.diff: kill __DATE__ with shell instead of patch
* Thu Apr 18 2013 jengelh@inai.de
- Supply path configuration file and kill the shell wrappers that
  supplied the paths via command line before.
* Tue Apr  9 2013 jengelh@inai.de
- Update to new upstream release 1.10
  * the multiplayer server is now its own separate executable that
  users control using the new "Shell" application
- Remove deng-libdir.diff (merged upstream)
* Tue Mar 19 2013 schwab@suse.de
- deng-va-list.diff: Remove non-portable use of va_list
* Sun Feb 17 2013 jengelh@inai.de
- Correctly place files into %%_libdir (original sr#147463)
* Sun Jan  6 2013 jengelh@inai.de
- Update to new upstream release 1.9.10.1
  * The longstanding gameplay bug that prevented a column from
  lowering on Doom E1M7 has now been fixed.
  * Command-line tools for creating and editing data files (md2tool,
  texc) are now included as part of the distribution packages.
* Thu Oct  4 2012 jengelh@inai.de
- Update to new upstream release 1.9.9
  * Faster map loading thanks to optimizations in the BSP builder.
  * Improved music support for OS X 10.6+ and Linux: SF2 soundfonts
  can be used with the original games' MIDI music.
* Mon Jul  9 2012 jengelh@inai.de
- Bump importance of timidity from Suggested to Recommended. (Few
  users actually have FMOD (alternative output plugin) installed.)
* Sun Jun 24 2012 jengelh@inai.de
- Initial package (version 1.9.8) for build.opensuse.org
